
library(CSTools)
library(startR)
library(s2dv)
source('/esarchive/scratch/jramon/GitLab_jramon/downscaling/csdownscale/R/Interpolation.R')
source('/esarchive/scratch/jramon/GitLab_jramon/downscaling/csdownscale/R/Intlr.R')
source('/esarchive/scratch/jramon/GitLab_jramon/downscaling/csdownscale/R/Utils.R')

plotpath <- '/esarchive/scratch/jramon/downscaling/plots'
target_grid <- '/esarchive/recon/ecmwf/era5/daily/tasmax-r1440x721cds/tasmax_201702.nc'

lonmin <- -22
lonmax <- 45
latmin <- 27
latmax <- 72

sdates <- c('20170201','20170301','20170401','20170501','20170601','20170701','20170801','20170901')

obs <- CST_Load(var = 'tasmax', obs = 'era5', sdates = sdates, leadtimemax = 1,
                latmin = latmin, latmax = latmax, lonmin = lonmin, lonmax = lonmax,
                output = 'lonlat')
obs$data <- drop(obs$data)

exp <- CST_Load(var = 'tasmax', exp = 'system5c3s', nmember = 3, sdates = sdates, leadtimemax = 1,
                latmin = latmin, latmax = latmax, lonmin = lonmin, lonmax = lonmax,
                output = 'lonlat')

#ind rdm ha de ser o bé un vector o bé un array amb una dimensió anomenada 'sdate'
ind_rdm <- array(NA, dim = c('sdate' = 8,'vars' = 2))
ind_rdm[,1] <- rnorm(n=8,mean=0,sd=1)
ind_rdm[,2] <- rnorm(n=8,mean=0,sd=1)

int_method <- 'bil'
lr_methods <- c('basic', 'large-scale', '4nn')

for (i in seq(lr_methods)) {

  if (lr_methods[i] == 'large-scale') {
    predictors <- ind_rdm
  } else  {
    predictors <- NULL
  }
  downscaled <- Intlr(exp = exp, obs = obs, target_grid = target_grid, lr_method = lr_methods[i],
                      int_method = int_method, predictors = predictors, loocv = TRUE, ncores = 4)
  lats <- downscaled$lat
  lons <- downscaled$lon
  data <- downscaled$data
  s2dv::PlotEquiMap(var = data[1,1,1,1,,], lat = lats, lon = lons, filled.continents = FALSE,
                    toptitle = paste0(int_method, ' ', lr_methods[i]), brks = seq(250,310,5),
                    fileout = file.path(plotpath, paste0(int_method, ' ', lr_methods[i],'-lr.png')))
}

# Predictions
s2dv::PlotEquiMap(var = exp$data[1,1,1,1,,], lat = exp$lat, lon = exp$lon, filled.continents = FALSE,
                  toptitle = "Predictions Europe", brks = seq(250,310,5),
                  fileout = file.path(plotpath, "Predictions_Europe.png"))

# Observations
s2dv::PlotEquiMap(var = obs$data[1,,], lat = obs$lat, lon = obs$lon, filled.continents = FALSE,
                  toptitle = "Observations Europe", brks = seq(250,310,5),
                  fileout = file.path(plotpath, "Observations_Europe.png"))






